/// <reference types="node" />
import * as url from 'url';
import { EventEmitter2 as EventEmitter } from 'eventemitter2';
import { HttpHeaders, IAsyncHTMLElement, IFetchOptions, NetworkData, Problem, ProblemLocation, Severity, IFormatter, HintResources } from './types';
import { Configuration } from './config';
import { Category } from './enums/category';
export declare class Engine extends EventEmitter {
    private parsers;
    private hints;
    private connector;
    private messages;
    private browserslist;
    private ignoredUrls;
    private _formatters;
    private _timeout;
    readonly pageDOM: object | undefined;
    readonly pageContent: Promise<string> | undefined;
    readonly pageHeaders: HttpHeaders | undefined;
    readonly targetedBrowsers: Array<string>;
    readonly formatters: Array<IFormatter>;
    readonly timeout: number;
    private isIgnored;
    constructor(config: Configuration, resources: HintResources);
    onHintEvent(id: string, eventName: string, listener: Function): void;
    fetchContent(target: string | url.URL, headers?: object): Promise<NetworkData>;
    evaluate(source: string): Promise<any>;
    close(): Promise<void>;
    report(hintId: string, category: Category, severity: Severity, sourceCode: string, location: ProblemLocation | null, message: string, resource: string): void;
    clean(fileUrl: url.URL): void;
    clear(): void;
    notify(): Promise<void>;
    executeOn(target: url.URL, options?: IFetchOptions): Promise<Array<Problem>>;
    querySelectorAll(selector: string): Promise<Array<IAsyncHTMLElement>>;
    emitAsync(event: string | Array<string>, ...values: Array<any>): Promise<Array<any>>;
}
